from map import Map
from pygsear.Drawable import MultiImage

class Tile():
    def __init__(self, kind, pos, tileset):
        dirname = 'data/images/' + tileset
        
        #default tile - the endless black void
        images = ['void.png']
        self.walkable = False
        self.kind = kind
        self.pos = pos

        if kind is 'W':     #Wall
            images = ['wall.png']
        elif kind is '%':   #Keydoor
            images = ['doorkey1.png','doorkey2.png']
        elif kind is '*':   #Buttondoor
            images = ['doortrigger1.png', 'doortrigger2.png']
        elif kind is 'B':   #Button
            images = ['console1.png', 'console2.png']
        elif kind is 'C':   #Crate
            images = ['crate.png', 'ground.png']
            
        elif kind is 'G':   #Ground
            self.walkable = True
            images = ['ground.png', 'crate.png']
        elif kind is 'T':   #Trigger - walk on this to let guards loose
            images = ['ground.png']
            self.walkable = True
        elif kind is 'K':   #Keys
            self.walkable = True
            images = ['key.png', 'ground.png']
        elif kind is 'S':   #Start
            self.walkable = True
            images = ['stairs1.png', 'stairs1_2.png']
        elif kind is 'E':   #Exit
            self.walkable = True
            images = ['stairs2.png']

        self.image = MultiImage(dirname=dirname,
                                filenames=images,
                                defaultImage=images[0],
                                colorkey=None)
        self.image.flip(images[0])
        self.image.set_position(location=self.pos)

    def open_keydoor(self):
        self.walkable = True
        self.image.flip('doorkey2.png')

    def open_buttondoor(self):
        self.walkable = True
        self.image.flip('doortrigger2.png')

    def switch_button(self):
        self.kind = 'W'
        self.image.flip('console2.png')

    def move_crate(self, desttile):
        """Crate and destined ground tile switch position"""
        self.image.flip('ground.png')
        self.kind = 'G'
        self.walkable = True
        desttile.image.flip('crate.png')
        desttile.kind = 'C'
        desttile.walkable = False

    def remove_key(self):
        self.image.flip('ground.png')
        self.kind = 'G'


class GfxMap():
    """
    start, exit, buttondoor
    """
    def __init__(self, filename):
        m = Map(filename=filename)
        self.tiles = []
        tilesize=32
        tileset = m.tileset
        y = 32
        self.trigger = False
        
        for rows in m.tilemap:
            x = 0
            line = []
            for tiletype in rows:
                line.append(Tile(kind=tiletype, pos=(x,y), tileset=tileset))
                if tiletype is 'S':
                    self.start = (x, y)
                elif tiletype is 'E':
                    self.exit = (x, y)
                elif tiletype is '*':
                    self.buttondoor = (x, y)
                elif tiletype is 'T':
                    self.trigger = True
                
                x += 32
            self.tiles.append(line)
            y += 32

            
